@@ -4,7 +4,15 @@
 #include <cstdint>
 #include <cmath>
 #include <vector>
-#include "fmath.hpp"
+
+#ifdef __x86_64__
+    #include "fmath.hpp"
+    #define mm_gamma(x) fmath::fastgamma3(x)
+    #define mm_exp(x) fmath::expd(x)
+#else
+    #define mm_gamma(x) tgamma(x)
+    #define mm_exp(x) exp(x)
+#endif
 
 using namespace std;
 
